@@ -15,16 +15,29 @@ from starlette.responses import *
 from starlette.requests import Request
 from starlette.staticfiles import StaticFiles
 
-from fastapi import FastAPI, Form, Depends, File, UploadFile
+from fastapi import FastAPI, Form, Depends, File, UploadFile, Body
 
 
 class App(object):
+    """
+    from appzoo import App
+    app = App()
+    app_ = app.app
+    app.add_route()
+
+    if __name__ == '__main__':
+        app.run(f"{app.app_file_name(__file__)}:app_", port=9955, debug=True)
+    """
 
     def __init__(self, verbose=True):
         self.app = FastAPI()
         self.verbose = verbose  # 是否返回请求体
+
+        # 原生接口
         self.get = self.app.get
         self.post = self.app.post
+        self.api_route = self.app.api_route
+        self.mount = self.app.mount
 
     def run(self, app=None, host="0.0.0.0", port=8000, workers=1, access_log=True, debug=False, **kwargs):
         """
@@ -88,7 +101,7 @@ class App(object):
         """
         if method == 'GET':
             async def handler(request: Request):
-                input = dict(request.query_params)
+                input = request.query_params._dict
                 return self._try_func(input, func, result_key, **kwargs)
 
         elif method == 'POST':
@@ -96,6 +109,38 @@ class App(object):
                 input = kwargs_
                 return self._try_func(input, func, result_key, **kwargs)
 
+        # todo: def get_and_post(request: Request, kwargs = Body(None)):
+        else:
+            async def handler():
+                return {'Warning': 'method not in {"GET", "POST"}'}
+
+        return handler
+
+    def _handler_new(self, func, method='GET', result_key='data', **kwargs):
+        """
+
+        :param func:
+        :param method:
+            get -> request: Request
+            post -> kwargs: dict
+        :param result_key:
+        :return:
+        """
+
+        if method == 'GET':
+            async def handler(request: Request):
+                input = request.query_params._dict
+                return self._try_func(input, func, result_key, **kwargs)
+
+        elif method == 'POST':
+            async def handler(kwargs_: dict):  # todo 表单 request.form()
+                input = kwargs_
+                return self._try_func(input, func, result_key, **kwargs)
+
+        # todo: def get_and_post(request: Request):
+        # query_input = request.query_params._dict
+        # body_input = await request.request.json()
+
         else:
             async def handler():
                 return {'Warning': 'method not in {"GET", "POST"}'}
@@ -126,6 +171,9 @@ class App(object):
     def app_file_name(self, file=__file__):
         return Path(file).stem
 
+    def app_from(self, file=__file__, app='app_'):
+        return f"{Path(file).stem}:{app}"
+
 
 if __name__ == '__main__':
     import uvicorn
