@@ -23,8 +23,6 @@ def func():
     return 'OK'
 
 
-print('xxx')
-
 #########################个性化#########################
 
 
@@ -33,8 +31,5 @@ if __name__ == '__main__':
 
     import uvicorn
 
-    uvicorn.config.LOGGING_CONFIG['formatters']['access'][
-        'fmt'] = '%(asctime)s - %(levelprefix)s %(client_addr)s - "%(request_line)s" %(status_code)s'
-
     # debug
-    app.run(f"{app.app_file_name(__file__)}:app_", port=9000, debug= not is_open())
+    app.run(app.app_from(__file__), port=9000, debug=not is_open())
