@@ -6,7 +6,7 @@
 # @Author       : yuanjie
 # @Email        : yuanjie@xiaomi.com
 # @Software     : PyCharm
-# @Description  : 
+# @Description  : supervisor https://www.cnblogs.com/wxwgk/p/13258401.html
 # https://www.jianshu.com/p/fecf15ad0c9a
 import os
 import re
@@ -15,7 +15,7 @@ import gevent.monkey
 
 gevent.monkey.patch_all()
 
-dev = False if re.search('.c3_|.c4_', os.environ.get('DOCKER_JOBNAME', '')) else True
+dev = True
 debug = reload = dev
 bind = '0.0.0.0:8000'
 
@@ -27,10 +27,10 @@ pidfile = "log/gunicorn.pid"
 
 # 启动的进程数
 daemon = not dev  # 开启后台
-workers = multiprocessing.cpu_count() * 2 + 1
+workers = multiprocessing.cpu_count()
 threads = 1
 worker_class = 'gevent'  # -k gevent
 x_forwarded_for_header = 'X-FORWARDED-FOR'
 
-if __name__ == '__main__':
-    os.system("gunicorn -c gun.py flask_app:app")
+# if __name__ == '__main__':
+#     os.system("gunicorn -c gun.py flask_app:app")
